Module activity

Module activity 

Structs

ChainedChoices
IncorporatedChoices
MappedChoices
NoActivity
NoActivity can be used as a placeholder where an Activity is required but it doesn’t need to do anything.

Enums

LiftedActivityChoices

Traits

Activity
The Activity trait describes an activity that can be performed within a domain. An activity yields action choices for an agent where those choices may depend on the state of the agent. These action choices can be examined by a planner to discover a valid or optimal sequence of actions to reach a goal.
ActivityModifier
The ActivityModifier can be used to change the behaviors of an activity, e.g. by enforcing constraints.