Module keyed

Module keyed 

Structs

SelfKeyring
Implements a Keyring for states that implement SelfKey.
SelfPartialKeyring

Traits

Key
The Key trait describes objects that can be used as Keys by Keyed domains.
Keyed
Keyed is used to indicate an associated Key type for a struct.
Keyring
The Keyring trait is implemented by structs that can produce a key for a given state.
PartialKeyed
SelfKey
If a State contains its own key, it can implement SelfKey so that its key can be obtained without a Keyring.