Cell

Struct Cell 

pub struct Cell {
    pub x: i64,
    pub y: i64,
}

Fields

x: i64y: i64

Implementations

Source

impl Cell

pub fn new(x: i64, y: i64) -> Self

Make a new cell from a pair of indices.

pub fn from_point(p: Point, cell_size: f64) -> Self

Get the cell that this point is inside of. Points that are perfectly on the edge between two cells will be biased towards the cell with the higher index value.

pub fn bottom_left_point(&self, cell_size: f64) -> Point

Get the point on the “bottom left” (lowest coordinate values) corner of the cell.

pub fn bottom_right_point(&self, cell_size: f64) -> Point

pub fn top_left_point(&self, cell_size: f64) -> Point

pub fn top_right_point(&self, cell_size: f64) -> Point

pub fn center_point(&self, cell_size: f64) -> Point

Get the point in the center of the cell.

pub fn shifted(&self, x: i64, y: i64) -> Self

Get a new cell that is the same as this one, but shifted in x and y by the given values.

pub fn in_visible_quadrant_of( &self, other_cell: &Cell, other_status: CornerStatus, ) -> bool