Motion

Trait Motion 

pub trait Motion<Position, Velocity> {
    // Required methods
    fn compute_position(
        &self,
        time: &TimePoint,
    ) -> Result<Position, InterpError>;
    fn compute_velocity(
        &self,
        time: &TimePoint,
    ) -> Result<Velocity, InterpError>;
}

Required Methods

fn compute_position(&self, time: &TimePoint) -> Result<Position, InterpError>

Compute the position of this motion at a specific time. If the requested time is outside the bounds of the motion, then this will return an Err.

fn compute_velocity(&self, time: &TimePoint) -> Result<Velocity, InterpError>

Compute the velocity of this motion at a specific time. If the requested time is outside the bounds of the motion, then this will return an Err.

Implementors

Source

impl Motion<Isometry<f64, Unit<Complex<f64>>, 2>, Velocity> for mapf::motion::se2::timed_position::Motion

Source

impl Motion<OPoint<f64, Const<2>>, Matrix<f64, Const<2>, Const<1>, ArrayStorage<f64, 2, 1>>> for mapf::motion::r2::timed_position::Motion

Source

impl<'a, W: Waypoint> Motion<<W as Waypoint>::Position, <W as Waypoint>::Velocity> for TrajectoryMotion<'a, W>