Re-exports
pub use cost::Cost;pub use action_map::*;pub use activity::*;pub use closable::*;pub use configurable::*;pub use conflict::*;pub use connectable::*;pub use define_trait::*;pub use domain_map::*;pub use extrapolator::*;pub use informed::*;pub use initializable::*;pub use keyed::*;pub use reversible::*;pub use satisfiable::*;pub use space::*;pub use state_map::*;pub use weighted::*;
Modules
- action_
map - activity
- closable
- configurable
- conflict
- connectable
- cost
- define_
trait - domain_
map - extrapolator
- informed
- initializable
- keyed
- reversible
- satisfiable
- space
- state_
map - weighted
Traits
- Domain
- A domain that is being planned over must, at a minimum, specify a type for its state representation and a type for errors that may occur while using the domain.