The Activity trait describes an activity that can be performed within a
domain. An activity yields action choices for an agent where those choices
may depend on the state of the agent. These action choices can be examined
by a planner to discover a valid or optimal sequence of actions to reach a
goal.