pub struct Cell {
pub x: i64,
pub y: i64,
}Fields
x: i64y: i64Implementations
Sourceimpl Cell
impl Cell
Sourcepub fn from_point(p: Point, cell_size: f64) -> Self
pub fn from_point(p: Point, cell_size: f64) -> Self
Get the cell that this point is inside of. Points that are perfectly on the edge between two cells will be biased towards the cell with the higher index value.
Sourcepub fn bottom_left_point(&self, cell_size: f64) -> Point
pub fn bottom_left_point(&self, cell_size: f64) -> Point
Get the point on the “bottom left” (lowest coordinate values) corner of the cell.
pub fn bottom_right_point(&self, cell_size: f64) -> Point
pub fn top_left_point(&self, cell_size: f64) -> Point
pub fn top_right_point(&self, cell_size: f64) -> Point
Sourcepub fn center_point(&self, cell_size: f64) -> Point
pub fn center_point(&self, cell_size: f64) -> Point
Get the point in the center of the cell.
Sourcepub fn shifted(&self, x: i64, y: i64) -> Self
pub fn shifted(&self, x: i64, y: i64) -> Self
Get a new cell that is the same as this one, but shifted in x and y by the given values.
pub fn in_visible_quadrant_of( &self, other_cell: &Cell, other_status: CornerStatus, ) -> bool