pub trait Motion<Position, Velocity> {
// Required methods
fn compute_position(
&self,
time: &TimePoint,
) -> Result<Position, InterpError>;
fn compute_velocity(
&self,
time: &TimePoint,
) -> Result<Velocity, InterpError>;
}Required Methods
Sourcefn compute_position(&self, time: &TimePoint) -> Result<Position, InterpError>
fn compute_position(&self, time: &TimePoint) -> Result<Position, InterpError>
Compute the position of this motion at a specific time. If the requested time is outside the bounds of the motion, then this will return an Err.
Sourcefn compute_velocity(&self, time: &TimePoint) -> Result<Velocity, InterpError>
fn compute_velocity(&self, time: &TimePoint) -> Result<Velocity, InterpError>
Compute the velocity of this motion at a specific time. If the requested time is outside the bounds of the motion, then this will return an Err.